document.addEventListener("DOMContentLoaded", init);

async function init() {
	const options = await getOptions();

	for (const actionSelectionElement of document.querySelectorAll('.action-selection')) {
		actionSelectionElement.innerHTML = `
			<option value="none">NONE</option>
			<option value="navigateBack">NAVIGATE BACK</option>
			<option value="navigateForward">NAVIGATE FORWARD</option>
			<option value="reload">RELOAD PAGE</option>
			<option value="createNewTab">CREATE NEW TAB</option>
			<option value="closeCurrentTab">CLOSE CURRENT TAB</option>
			<option value="undoCloseTab">RESTORE LAST CLOSED TAB</option>
			<option value="activateLeftTab">ACTIVATE LEFT TAB</option>
			<option value="activateLeftTabSkipSpecial">ACTIVATE LEFT TAB - skip special pages</option>
			<option value="activateRightTab">ACTIVATE RIGHT TAB</option>
			<option value="activateRightTabSkipSpecial">ACTIVATE LEFT TAB - skip special pages</option>`
	}

	const getElementById = (id) => document.getElementById(id);

	for (optionName in options) {
		if (optionName.endsWith('Enabled')) {
			getElementById(optionName).checked = options[optionName];
		} else if (optionName.endsWith('Action') || optionName === 'minDelta') {
			getElementById(optionName).value = options[optionName];
		}
	}

	getElementById('minDelta-display-value').textContent = options.minDelta + "px";

	function updateActivationForCheckboxElement(checkboxElement) {
		if (checkboxElement.classList.contains('enableGestureCheckbox')) {
			const selectElement = document.querySelector(`label[for="${checkboxElement.id}"] select`);

			if (selectElement) {
				selectElement.disabled = !checkboxElement.checked;
			}
		}
	}

	for (const checkboxElement of document.querySelectorAll('input[type="checkbox"]')) {
		checkboxElement.onchange = async function (event) {
			const targetElement = event.target;
			updateActivationForCheckboxElement(targetElement);
			options[targetElement.id] = targetElement.checked;
			await setOptions(options);

		}

		updateActivationForCheckboxElement(checkboxElement);
	}

	for (const selectElement of document.querySelectorAll('select')) {
		selectElement.onchange = async function (event) {
			const targetElement = event.target;
			options[targetElement.id] = targetElement.value;
			await setOptions(options);
		}
	}

	getElementById('minDelta').oninput = (event) => {
		getElementById('minDelta-display-value').textContent = event.target.value + "px";
	}

	getElementById('minDelta').onchange = async (event) => {
		options.minDelta = event.target.value;
		await setOptions(options);
	}
}
